/**
 * Copyright (c) 2021 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#pragma once
#include "../../libs.h"
#include "../../file/asset.h"
#include "../../locale/language.h"
#include "../../display/texture.h"
#include "../../vn/vncharacter.h"
#include "../../poker/common.h"
#include "characters/characters.h"

typedef struct {
  font_t font;
  shader_t shader;
  language_t language;

  texture_t testTexture;
  texture_t roomTexture;
  texture_t cardTexture;

  texture_t characterTextures[POKER_PLAYER_COUNT_MAX];
} pokergameassets_t;

/**
 * Load and initializes all the assets used by the poker game.
 * 
 * @param assets Assets instance to initailize.
 * @return True if successful, otherwise false.
 */
bool pokerGameAssetsInit(pokergameassets_t *assets);

/**
 * Cleans a previously initialized game assets set.
 * 
 * @param assets Assets to dispose.
 */
void pokerGameAssetsDispose(pokergameassets_t *assets);